###### Phylogenomics Workshop Cesky Krumlov 2024 ########
#### Matt Christmas Seminar 27/01/2024 #########
#### Mammalian comparative genomics #####
#### matthew.christmas@imbim.uu.se #####

### Selective forces acting on sequence influence phylogenetic interpretation ###

# Here, we will carry out a short exercise to generate trees from sets of sites extracted from the Zoonomia alignment of 241 mammal genomes to test the effects of
# using sites under different selection pressures when estimating phylogenetic relationships.
# All the sites used are four-fold degenerate sites (so, in coding sequences) and I have used their base-wise phyloP scores to split them into three groups:
# "neutral", "constraint", and "acceleration"

# These are very small datasets (64-102 sites) to make the analysis run quickly, so the results we get aren't completely reliable but sufficient for demonstrating
# the effects of selection pressure on sequence evolution

#Load required packages for the phylogenetic analysis
library(tidyverse) # for making life in R easier. Includes ggplot2 for plotting
library(seqinr) # for importing in sequences in fasta format
library(DECIPHER) # for generating genetic distance matrices
library(ape) # for generating neighbour-joining (nj) trees
library(ggtree) # for plotting nice trees


# Bring in file containing info on the species in Zoonomia. This gives all the species names as well as the order and family they belong to. 
# We'll use this file for colouring the plots we generate

zoonomia_species <- read_delim("./zoonomia_species.txt", delim = "\t", escape_double = FALSE, trim_ws = TRUE)

# Let's first generate a tree using alignments of sites under high constraint (phyloP > 6, n = 64 sites)
## Read sequences from FASTA file

constrained_sites <- readDNAStringSet("4D_high_constraint_sites_chr3_genotypes.fasta")

## Generate distance matrix from fasta file. Each element of the distance matrix corresponds to the dissimilarity between two sequences 

constrained_dist_mat <- DistanceMatrix(constrained_sites)

# QUESTION: How many species pairs have a distance of zero? Is this likely to be true generally for these species, or specific to these sites?

# QUESTION: What is the average genetic distance among all species?


## compute neighbor joining (NJ) tree. NJ is a bottom-up clustering method that infers relationships between species by sequentially grouping those
## that show fewest differences (based on the genetic distance matrix) into an unrooted tree

constrained_sites_tree <- nj(constrained_dist_mat)

## display phylogenetic tree using ggtree

constrained_sites_tree_plot <- ggtree(constrained_sites_tree, layout='circular', size=0.2) #+ geom_tiplab()
# if we include the tip labels here (using 'geom_tiplab()') it becomes very crammed. Instead, we'll use information
# in our zoonmoia_species metadata file to colour the tip points by Order

# Add order colours
constrained_sites_tree_coloured <- constrained_sites_tree_plot %<+% zoonomia_species + # This merges the zoonomia_species columns with the plot so we can access information on 
  # which orer each species belongs to
  geom_tippoint(aes(colour = Order), size=0.5) +# This adds the order of each species as a coloured tip point :-)
  #geom_tiplab(aes(label=`Common Name`),size=2) + # we could also add tip labels, but it is too crowded
  geom_treescale()# This adds a scale bar to the tree


### Now let's do the same again but with a random set of sites under acceleration (-3 < phyloP > -2, n = 81 sites)
## Read sequences from FASTA file

accelerated_sites <- readDNAStringSet("4D_accelerated_sites_chr3_genotypes.fasta")

## Generate distance matrix from fasta file

accelerated_dist_mat <- DistanceMatrix(accelerated_sites)

# QUESTION: How many species pairs have a distance of zero now?

# QUESTION: What's the average genetic distance among all species?


## compute phylogenetic tree using neighbor joining

accelerated_sites_tree <- nj(accelerated_dist_mat)

## display phylogenetic tree using ggtree

accelerated_sites_tree_plot <- ggtree(accelerated_sites_tree, layout='circular', size=0.2) #+ geom_tiplab()

accelerated_sites_tree_coloured <- accelerated_sites_tree_plot %<+% zoonomia_species + 
  geom_tippoint(aes(colour = Order), size=0.5) +
  #geom_tippoint(aes(colour = Superorder), size=0.5) + # You can also colour by superorder - do they group as you would expect?
  geom_tiplab(aes(label=`Common Name`),size=2) +
  geom_treescale()


# And lastly using a random set of neutrally evolving sites (-0.1< phyloP > -0.1, n = 102 sites)
## Read sequences from FASTA file

neutral_sites <- readDNAStringSet("4D_neutral_sites_chr3_genotypes.fasta")

## Generate distance matrix from fasta file

neutral_dist_mat <- DistanceMatrix(neutral_sites)

# QUESTION: How many species pairs have a distance of zero now?

# QUESTION: What's the average genetic distance among all species?

## compute phylogenetic tree using neighbor joining

neutral_sites_tree <- nj(neutral_dist_mat)

## display phylogenetic tree using ggtree

neutral_sites_tree_plot <- ggtree(neutral_sites_tree, layout='circular', size=0.2) #+ geom_tiplab()

neutral_sites_tree_coloured <- neutral_sites_tree_plot %<+% zoonomia_species + 
  geom_tippoint(aes(colour = Order), size=0.5) +
  #geom_tippoint(aes(colour = Superorder), size=0.5) + You can also colour by superorder - do they group as you would expect?
  geom_tiplab(aes(label=`Common Name`),size=2) +
  geom_treescale()


# QUESTION: What are the overall conclusions you can make from this in terms of the effects of the underlying sequence on the phylogeny?




